function [model,likelihood] = directoptlearn(HeterogeneousProfiles, ReferenceProfiles)
%function [newmodel likelihood] = directoptlearn(HeterogeneousProfiles, ReferenceProfiles)
%
% INPUT:
%  HeterogeneousProfiles: a GxD matrix representing gene expression profiles of heterogeneous (mixed) samples, where G is the number of genes, D is the number of heterogeneous samples
%  ReferenceProfiles: a KxG matrix, representing the expression profiles of the K reference cell populations.  Note the dimensions (KxG)
%
% OUTPUT:
%
% likelihood: likelihood of the final model
%
% model: a structure with the following important fields:
%
% theta: a DxK matrix, giving the fractional composition of each heterogeneous sample.  Each row represents a heterogeneous sample that was part of the input.

more off;
NTOPICS = size(ReferenceProfiles,1);
INITIAL_ALPHA = rand(1,NTOPICS) + 1;  
INITIAL_ALPHA(end) = INITIAL_ALPHA(end)+5;

%convert HeterogeneousProfiles into a data structure used by the model
corpus = read_data(HeterogeneousProfiles);

%keep track of all likelihoods from all potential sites of origin
ReferenceProfiles = ReferenceProfiles ./ repmat(sum(ReferenceProfiles,2),1, size(ReferenceProfiles,2));

%add random amount since many elements may be 1 from before
currentReferenceProfiles = ReferenceProfiles;

%initialize a new ISOLATE model to learn, using the assumed current
%site of origin, the Source Panel gene abundances, and initial alpha
INIT_MODEL = new_model(corpus, INITIAL_ALPHA, currentReferenceProfiles);
    
[model likelihood] = optmodel(corpus.docs, INIT_MODEL);

