function [model likelihood] = optmodel(docs, model)
% function model = isolate_mle(model, ss, kappa)
%
% performs the M-step for parameter estimation.
%
% model: isolatemodel structure containing our model
%
% ss: sufficient statistics being collected across all tumor samples
%
% kappa: the kappa parameter on our Gamma prior, that controls how
% strongly we expect the scaling parameters to sit near 1
%
%
% OUTPUT:
%
% model: (updated) model


%sufficient statistics for cancer component is just the last row of ss.class_word
%siteoforigin_suffstats = ss.class_word(end,:)';

%update alpha variable

likelihood_old = -Inf;

NUM_GRID_SEARCH_ITERATIONS = 10;
NUM_ITERATIONS = 10;

for iter=1:NUM_ITERATIONS
    if (iter <= 50)
        NUM_ITERATIONS_RMINIMIZE=10;
    else
        NUM_ITERATIONS_RMINIMIZE=20;
    end
    
    disp('--- optimizing theta...');
    model = opt_theta(docs, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS);
    
    likelihood = compute_likelihood(docs, model);
    change_ll = likelihood-likelihood_old;
    
    disp(['iter: ' num2str(iter) '/' num2str(NUM_ITERATIONS) ', likelihood: ' num2str(likelihood) ', change: ' num2str(change_ll)]);
    
    likelihood_old = likelihood;
end

%last minimization of theta, such that we know we are at a minimum for theta
%cannot do in this case, because we aren't modifying theta in this case
disp('--- optimizing last round of theta...');
model = opt_theta(docs, model, 100, iter, NUM_GRID_SEARCH_ITERATIONS);
