function model = opt_theta(docs, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS)
%function alpha = opt_alpha(ss, NUM_DOCS, NUM_TOPICS)
%
%
% This function numerically optimizes for the alpha variables, using the
% conjugate gradient implementation by Carl Rasmussen
%
% INPUT:
%
% ss: sufficient statistics collected from tumor samples
%
% NUM_DOCS: number of tumor samples
%
% NUM_TOPICS: length of alpha (number of mixing sources)
%
% model: learned isolate model (from previous iteration)


%rminimize seems to only work on vectors - they are independent anyways

K = size(model.theta,2);
D = size(model.theta,1);

for dd=1:D
    ww = log(model.theta(dd,:))';
    
    %initial starting point
    init_xx = ww;
    [xx tmp num_iter] = rminimize(init_xx, 'theta_obj', NUM_ITERATIONS_RMINIMIZE,docs, dd, model);
    
    %re-exponentiate
    model.theta(dd,:) = exp(xx)'/sum(exp(xx));
       
    if (iter <= NUM_GRID_SEARCH_ITERATIONS)
        likelihood = theta_compute_likelihood(model.theta(dd,:), docs, dd, model);
        
        for randiter=1:25
            newtheta = rand(1,K);
            newtheta = newtheta ./ sum(newtheta);
            
            [xx tmp num_iter] = rminimize(log(newtheta'), 'theta_obj', NUM_ITERATIONS_RMINIMIZE, docs,dd, model);
            newtheta = exp(xx') ./ sum(exp(xx));
            newll = theta_compute_likelihood(newtheta, docs, dd, model);
            
            if (newll > likelihood)
                disp(['theta tumor ' num2str(dd) ' grid search found better solution.']);
                model.theta(dd,:) = newtheta;
                likelihood = newll;
            end
        end
    end
    
end

