function [myalhood, deriv_alhood] = theta_obj(ww, docs, doc_index, model)
%function [myalhood, deriv_alhood] = alpha_obj(a, ss, NUM_DOCS, NUM_TOPICS)
%
% This function returns the alhood and derivative of the alhood 
% with respect to log(alpha).  That is, we are assuming we are optimizing 
% the log of alpha, so that we can keep it positive.
%
% INPUT:
%
% NUM_DOCS: number of tumor samples
% 
% NUM_TOPICS: length of alpha (number of mixing sources)

expww = exp(ww');
theta = expww ./ sum(expww);

myalhood = 0;
W = size(model.log_prob_w,2);
K = size(model.log_prob_w,1);

%add ln P(t_d|\theta,\beta)
doccounts = docs{doc_index}.counts;

log_P_t_given_theta = logsum(   repmat( log(theta), W, 1)' + model.log_prob_w    , 1);
myalhood = myalhood + (log_P_t_given_theta * doccounts);


%dL/d(log_kappa) = dL/dkappa * dkappa/d(log_kappa)
%                = dL/dkappa * kappa
%dLdtheta = ((model.alpha-1)./theta) +   sum(  exp(model.log_prob_w - repmat(log_P_t_given_theta, K,1))' .* repmat(doccounts,1,K)         );
dLdtheta =  sum(  exp(model.log_prob_w - repmat(log_P_t_given_theta, K,1))' .* repmat(doccounts,1,K)         );


%set the first derivative to be zero, to set the scale of the w's
bb = expww ./sum(expww);
deriv_alhood = real(exp(logsum(log(dLdtheta) + log(bb),2) + log(bb)));
deriv_alhood = -deriv_alhood + (dLdtheta.*bb);

%dthetadw = -(expww'*expww)./(sum(expww)^2);
%dthetadw = dthetadw + diag(expww/sum(expww));
%set the first derivative to be zero, to set the scale of the w's
%dthetadw(1,:) = 0;
%dthetadw(:,1) = 0;

%deriv_alhood = (dLdtheta*dthetadw)';
deriv_alhood = deriv_alhood';

%set the first derivative to be zero, to set the scale of the w's
deriv_alhood(1) = 0;

%rasmussen's conjugate gradient method minimizes, so we negative the derivative and alhood
myalhood = -myalhood;
deriv_alhood = -deriv_alhood;
